@@ -2,14 +2,19 @@ use std::io;
 use std::io::{Read, Write};
 use termion::raw::IntoRawMode;
 
-pub fn getchar() -> u8{
+pub fn getchar() -> Result<u8, ()>{
     let mut buffer = [0];
     let stdout = io::stdout().into_raw_mode().unwrap();
     let mut stdin = io::stdin();
 
     stdout.lock().flush().unwrap();
-    stdin.read_exact(&mut buffer).unwrap();
 
-    buffer[0]
+    // TODO: this looks like it could be done more concisely
+    return if let Ok(_) = stdin.read_exact(&mut buffer){
+        Ok( buffer[0] )
+    }
+    else{
+        Err( () )
+    }
 }
 
